@@ -1,22 +1,8 @@
-/***********************************************************************
- * Copyright 2008 Ian Monroe <ian@monroe.nu>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- ***********************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Ian Monroe <ian@monroe.nu>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "discSelectionDialog.h"
 
@@ -101,7 +87,8 @@ DiscSelectionDialog::DiscSelectionDialog( QWidget* parent, const QList< Solid::D
     layout->addWidget(bbox);
     setLayout( layout );
 
-    connect( m_listWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(discItemSelected(QListWidgetItem*)) );
+    connect(m_listWidget, &QListWidget::itemDoubleClicked,
+            this, &DiscSelectionDialog::discItemSelected);
     connect( bbox, &QDialogButtonBox::accepted, this, &DiscSelectionDialog::okClicked);
     connect( bbox, &QDialogButtonBox::rejected, this, &QDialog::deleteLater );
     //connect( bbox, &QDialogButtonBox::rejected, const_cast<QObject *>(Dragon::mainWindow()), &Dragon::MainWindow::playDisc ); // kf5 FIXME? this could have never worked
